diff libpurple/certificate.h @ 19067:6c0aad79c4c5

- Change the internal structure of activation/expiration times to match the "NSS way", which is already how the libpurple public interface works - Change ssl-gnutls to match the above
author William Ehlhardt <williamehlhardt@gmail.com>
date Fri, 03 Aug 2007 06:12:42 +0000
parents c79b54f03f9d
children daa68185a018
line wrap: on
line diff
--- a/libpurple/certificate.h	Wed Aug 01 07:39:38 2007 +0000
+++ b/libpurple/certificate.h	Fri Aug 03 06:12:42 2007 +0000
@@ -235,10 +235,8 @@
 	 */
 	gboolean (* check_subject_name)(PurpleCertificate *crt, const gchar *name);
 
-	/** Retrieve the certificate activation time */
-	time_t (* get_activation)(PurpleCertificate *crt);
-	/** Retrieve the expiration time */
-	time_t (* get_expiration)(PurpleCertificate *crt);
+	/** Retrieve the certificate activation/expiration times */
+	gboolean (* get_times)(PurpleCertificate *crt, time_t *activation, time_t *expiration);
 	
 	/* TODO: Fill out this structure */
 };